/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -N -m -i ../generictypes.h -p siminterface
 * /home/devin/kde/src/modemmanager-qt/src/dbus/introspection/org.freedesktop.ModemManager1.Sim.xml
 *
 * qdbusxml2cpp is Copyright (C) 2023 The Qt Company Ltd and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#include "siminterface.h"

/*
 * Implementation of interface class OrgFreedesktopModemManager1SimInterface
 */

OrgFreedesktopModemManager1SimInterface::OrgFreedesktopModemManager1SimInterface(const QString &service,
                                                                                 const QString &path,
                                                                                 const QDBusConnection &connection,
                                                                                 QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopModemManager1SimInterface::~OrgFreedesktopModemManager1SimInterface()
{
}

#include "moc_siminterface.cpp"
